==> aquedart-5.0.1.tar.gz: test/command/document_server_test.dart <==
// ignore: unnecessary_const
@Tags(const ["cli"])
import 'dart:io';

import 'package:cli_agent/cli_agent.dart';
import 'package:test/test.dart';
import 'package:http/http.dart' as http;

import '../not_tests/cli_helpers.dart';

void main() {
  late CLIClient templateCli;
  late CLIClient projectUnderTestCli;

  setUpAll(() async {
    await CLIClient.activateCLI();
    templateCli = await CLIClient(CommandLineAgent(ProjectAgent.projectsDirectory)).createProject();
    await templateCli.agent.getDependencies(offline: true);
  });

  tearDownAll(() async {
    await CLIClient.deactivateCLI();
    ProjectAgent.tearDownAll();
  });

  setUp(() async {
    projectUnderTestCli = templateCli.replicate(Uri.parse("replica/"));
  });

  tearDown(() {
    projectUnderTestCli.agent.workingDirectory.deleteSync(recursive: true);
  });

  test("Can get API reference", () async {
    final task = projectUnderTestCli.start("document", ["serve"]);
    await task.hasStarted;

    expect(
        Directory.fromUri(
                projectUnderTestCli.agent.workingDirectory.uri.resolve(".aquedart_spec/"))
            .existsSync(),
        true);

    var response = await http.get(Uri.parse("http://localhost:8111"));
    expect(response.body, contains("redoc spec-url='openapi.json'"));

    // ignore: unawaited_futures
    task.process!.stop(0);
    expect(await task.exitCode, 0);
    expect(
        Directory.fromUri(
          projectUnderTestCli.agent.workingDirectory.uri.resolve(".aquedart_spec/"))
            .existsSync(),
        false);
  });
}

==> aquedart-5.0.2.tar.gz: test/command/document_server_test.dart <==
// ignore: unnecessary_const
@Tags(const ["cli"])
import 'dart:io';

import 'package:cli_agent/cli_agent.dart';
import 'package:test/test.dart';
import 'package:http/http.dart' as http;

import '../not_tests/cli_helpers.dart';

void main() {
  late CLIClient templateCli;
  late CLIClient projectUnderTestCli;

  setUpAll(() async {
    await CLIClient.activateCLI();
    templateCli =
        await CLIClient(CommandLineAgent(ProjectAgent.projectsDirectory))
            .createProject();
    await templateCli.agent.getDependencies(offline: true);
  });

  tearDownAll(() async {
    await CLIClient.deactivateCLI();
    ProjectAgent.tearDownAll();
  });

  setUp(() async {
    projectUnderTestCli = templateCli.replicate(Uri.parse("replica/"));
  });

  tearDown(() {
    projectUnderTestCli.agent.workingDirectory.deleteSync(recursive: true);
  });

  test("Can get API reference", () async {
    final task = projectUnderTestCli.start("document", ["serve"]);
    await task.hasStarted;

    expect(
        Directory.fromUri(projectUnderTestCli.agent.workingDirectory.uri
                .resolve(".aquedart_spec/"))
            .existsSync(),
        true);

    var response = await http.get(Uri.parse("http://localhost:8111"));
    expect(response.body, contains("redoc spec-url='openapi.json'"));

    // ignore: unawaited_futures
    task.process!.stop(0);
    expect(await task.exitCode, 0);
    expect(
        Directory.fromUri(projectUnderTestCli.agent.workingDirectory.uri
                .resolve(".aquedart_spec/"))
            .existsSync(),
        false);
  });
}
